# Launcher[![Release Version](https://img.shields.io/badge/release-1.1.3-red.svg)](https://git.dankal.cn/lihuaikun/androidlibrary/tree/master/cn/dankal/android/launcher/1.1.3)
1. 添加依赖配置
    ```groovy
    //在build.gradle中添加maven
    repositories {
    maven {url "https://git.dankal.cn/lihuaikun/androidlibrary/raw/master"}
    ...
    }

    dependencies {
    implementation 'cn.dankal.android:launcher:1.1.0'
    }
    ```
2. AndroidManifests.xml配置

    **Application节点的theme必须继承LauncherTheme或者直接使用android:theme="@style/LauncherTheme"\[必须]**
    
3. 初始化

    ```java
    //在Application的onCreate中插入代码
    //SettingActivity表示拦截系统设置后跳转的页面
    LauncherManager.init(this, SettingActivity.class);
    ```
4. 对应用添加使用规则
    ``` java
    ManagementInfo managementInfo = new ManagementInfo();
    managementInfo.setPackageName("com.tencent.tim");   

    //    正常使用
    // 此枚举类型已注销 ColumnDef.AppUseType.NORMAL_TYPE ~~
    
    
    // 学习教育类
    //ColumnDef.AppUseType.LEARN_TYPE
    //    游戏类应用
    //ColumnDef.AppUseType.GAME_LOCK_TYPE

    //    未分类应用
    //ColumnDef.AppUseType.UNCLASS_TYPE  
    
    //无需管控类
    //ColumnDef.AppUseType.SAFE_TYPE
     
    managementInfo.setUseType(ColumnDef.AppUseType.GAME_LOCK_TYPE);
    //app锁定模式
    //        应用使用时长到达上限
    ColumnDef.LockApp.DEADLINE
    //        应用锁定
    ColumnDef.LockApp.LOCKED
    //        应用未锁定
    ColumnDef.LockApp.UNLOCKED
    
    
    managementInfo.setLock(ColumnDef.LockApp.LOCKED);
    
    //设置秒级时间戳 应用可使用的截止时间戳
    managementInfo.setUseEndTimeStamp(1583897604);
    //设置单个应用 
    LauncherManager.getInstance().addPackageInfo(managementInfo);    

    //设置多个应用
    List<ManagementInfo> managementInfoList = new ArrayList<>(); LauncherManager.getInstance().addPackageInfo(managementInfoList);

    //删除某个应用规则
    LauncherManager.getInstance().removePackageInfo("com.tencent.tim");

    //删除多个应用

    List<String> managementInfoList = new ArrayList<>(); LauncherManager.getInstance().removePackageInfoList(managementInfoList);
    
    //获取受管理的app信息
    LauncherManager.getInstance().getAppInfo();
    
    ```
5. 返回桌面/跳转设置
   
    ```java
    
    //直接返回桌面
    LauncherManager.getInstance().backLauncherHome(Context context);
    //返回桌面并dialog提示
    LauncherManager.getInstance().backLauncherHome(Context context,String dialogTip);
    //跳转设置
    LauncherManager.getInstance().jumpSetting(Context context);
    ```
 
6. 设置锁屏模式/解锁屏幕
    ```java
    //锁屏 永久锁屏 需要手动调用unlockScreen解锁
    LauncherManager.getInstance().forceLockScreenForever(Context context);
    
	//锁屏 timestamp秒 时间过期后会自动使用当前工作模式下的锁屏模式
	LauncherManager.getInstance().forceLockScreen(Context context，long timestamp);

    //解锁屏幕
    LauncherManager.getInstance().unlockScreen();
    ```
7. 设置管控周期规则
	```java
   List<Long> regions = new ArrayList<>();
   //regions成对出现 每一对表示一个可以使用的时间段
   regions.add(Long.valueOf(9 * 3600));//起始时间 9*3600=当天的早上九点
   regions.add(Long.valueOf(19 * 3600));//结束时间
   //设置管控配置	 
   TimeConfig config= new TimeConfig.Builder(ColumnDef.TimeManager.WORK_DAY) //管控类型 WORK_DAY=工作日 WEEK_RESET=周末 HOLIDAY_MODE=假日
                       .lockScreenMode(ColumnDef.LockScreen.MODE_UNLOCK) //指定不包含regions的时间段中的锁屏模式
                       .addUseRegion(regions) //用户可使用的时间段
                       .addAppTypeConfig(ColumnDef.AppUseType.GAME_LOCK_TYPE, 60) //指定某一类别的app每天可使用的最大时长
                       .build();
   //添加管控配置
   LauncherManager.getInstance().addWorkMode(config);
   //设置当前的工作模式（主要是针对假日模式，其他两个模式会根据当前时间自动变换，
   //在假日模式过期之后需要主动调用此方法设置为其他模式）
   LauncherManager.getInstance().setCurrentWorkMode(ColumnDef.TimeManager.WORK_DAY);
	```

 

    
 